<?xml version="1.0" encoding="UTF-8" ?>
<!-- 
Feuille de style présentant les produits d'un marchand
+ une fonctionnalité de recherche

Usage (exemple) :
java -jar saxon9he.jar docsource.xml marchand1.xsl begin=ba

Auteur : Matthias Colin
Version : 1.0 (23/03/2011)
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" version="2.0" >

<!-- motif à rechercher sur le début d'un libellé de produit -->
<xsl:param name="begin" />
	
<xsl:output method="html" encoding="UTF-8" />
 
<xsl:template match="marchand">
<html>
<head><title><xsl:value-of select="@nom" /></title></head>
<body>
<h1><xsl:value-of select="@nom" /></h1>
<h2>Liste des produits (par libellé)</h2>
<table>
<xsl:for-each select="//produit">
	<xsl:sort select="@libelle" />
	<xsl:apply-templates select="." />
</xsl:for-each>
</table>
		
<h2>Liste des produits (par prix)</h2>
<table>
<xsl:for-each select="//produit">
	<xsl:sort select="xs:decimal(@prix)" order="descending" />
	<xsl:apply-templates select="." />
</xsl:for-each>
</table>
		
<h2>Statistiques</h2>
<table>
<tr><th>Pays</th>
<th>Nombre de Produits</th>
<th>Prix Moyen</th>
</tr>
<xsl:for-each-group select="//produit" group-by="@origine">
	<tr>
	<td><xsl:value-of select="current-grouping-key()" /></td>
	<td><xsl:value-of select="count(current-group())" /></td>
	<td><xsl:value-of select="format-number(avg(current-group()/@prix), '#.##')" /></td>
	</tr>
</xsl:for-each-group>
</table>

<xsl:if test="$begin">
	<h2>Recherche des produits commençant par : <value-of select="$begin" /></h2>
	<table>
	<xsl:for-each select="//produit[starts-with(lower-case(@libelle), lower-case($begin))]">
		<xsl:apply-templates select="." />
	</xsl:for-each>
	</table>
</xsl:if>

</body>
</html>
</xsl:template>
	
<xsl:template match="produit">
<tr>
<td><xsl:value-of select="@libelle" /></td>
<td><xsl:value-of select="@prix" /></td>
<td><xsl:value-of select="@origine" /></td>
<td><!-- hiérarchie des rayons -->
<!-- avec un value-of ou un for-each :
	<xsl:value-of select="ancestor::rayon/@libelle" separator="#"/> 
-->
<xsl:for-each select="ancestor::rayon">
	<xsl:sort select="xs:integer(@niveau)" />
	<xsl:value-of select="@libelle" />
	<xsl:if test="not(position() = last())"> # </xsl:if>
</xsl:for-each>
</td>
<td><!-- description facultative -->
<xsl:choose>
	<xsl:when test="description">
	<xsl:value-of select="description" />
	</xsl:when>
	<xsl:otherwise>NC</xsl:otherwise>
</xsl:choose>
</td>
</tr>
</xsl:template>

</xsl:stylesheet>
